import { CommonModule } from '@angular/common';
import { Pipe, NgModule, InjectionToken, ɵɵdefineInjectable, ɵɵinject, Injectable, Inject, Optional } from '@angular/core';
import { asHTML } from '@prismicio/helpers';
import { DomSanitizer } from '@angular/platform-browser';
import { Router } from '@angular/router';
import { getEndpoint, createClient, cookie } from '@prismicio/client';
import { from } from 'rxjs';
import { map } from 'rxjs/operators';
import { __awaiter } from 'tslib';

/**
 * This pipe is used to render an array of Prismic Paragraphs
 * to HTML.
 *
 * @example
 * <!-- text is an array of paragraphs -->
 * <ng-container [innerHTML]="doc.data.text | renderHtml"></ng-container>
 */
class RenderHtmlPipe {
    /**
     * Takes Paragraphs and renders them to HTML.
     * It is possible to use a custom serializer function to change rendering
     * of certain elements, for example to add classes to standard tags.
     *
     * @param value paragraph definition to render
     * @param htmlSerializer optional HtmlResolver which modifies the rendering of certain elements
     */
    transform(value, htmlSerializer) {
        if (!(Array.isArray(value) && value.length > 0)) {
            return '';
        }
        return asHTML(value, undefined, htmlSerializer);
    }
}
RenderHtmlPipe.decorators = [
    { type: Pipe, args: [{
                name: 'renderHtml'
            },] }
];

/**
 * This pipe is used to render a Prismic Image to HTML.
 *
 * @example
 * <ng-container [innerHTML]="doc.image | renderImage : 'my extra classes'"></ng-container>
 */
class RenderImagePipe {
    /**
     * Renders an image object returned from Prismic to HTML.
     *
     * @param image image object returned from Prismic
     * @param imgTitle optional title for the image
     * @param imgClasses optional classes for the image
     * @param caption optional <figcaption>
     */
    transform(image, imgTitle, imgClasses, caption) {
        const classes = imgClasses ? ` class="${imgClasses}"` : '';
        const alt = image.alt ? ` alt="${image.alt}"` : '';
        const title = imgTitle ? ` title="${imgTitle}"` : '';
        const src = ` src="${image.url}"`;
        const img = `<img${classes}${alt}${title}${src}>`;
        if (caption) {
            return `<figure>${img}<figcaption>${asHTML(caption)}</figcaption></figure>`;
        }
        return img;
    }
}
RenderImagePipe.decorators = [
    { type: Pipe, args: [{
                name: 'renderImage'
            },] }
];

/**
 * A Pipe to easily sanitize different types of content.
 *
 * Credit goes to Swarna:
 * https://medium.com/@swarnakishore/angular-safe-pipe-implementation-to-bypass-domsanitizer-stripping-out-content-c1bf0f1cc36b
 */
class SafePipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(value, type) {
        switch (type) {
            case 'html': return this.sanitizer.bypassSecurityTrustHtml(value);
            case 'style': return this.sanitizer.bypassSecurityTrustStyle(value);
            case 'script': return this.sanitizer.bypassSecurityTrustScript(value);
            case 'url': return this.sanitizer.bypassSecurityTrustUrl(value);
            case 'resourceUrl': return this.sanitizer.bypassSecurityTrustResourceUrl(value);
            default: throw new Error(`Invalid safe type specified: ${type}`);
        }
    }
}
SafePipe.decorators = [
    { type: Pipe, args: [{
                name: 'safe'
            },] }
];
SafePipe.ctorParameters = () => [
    { type: DomSanitizer }
];

class PrismicClientModule {
}
PrismicClientModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    RenderHtmlPipe,
                    RenderImagePipe,
                    SafePipe
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    RenderHtmlPipe,
                    RenderImagePipe,
                    SafePipe
                ]
            },] }
];

/**
 * Name of your prismic repository.
 */
const REPOSITORY_NAME = new InjectionToken('REPOSITORY_NAME');
/**
 * Injection token to provide a link resolver function.
 *
 * This could be done based on doc type and uid.
 */
const LINK_RESOLVER = new InjectionToken('LINK_RESOLVER');
/**
 * Injection token to provide a custom fallback route for link resolving.
 * Default is `/`.
 */
const LINK_RESOLVER_DEFAULT_ROUTE = new InjectionToken('LINK_RESOLVER_DEFAULT_ROUTE');
/**
 * Injection token to provide the URL for the link resolver.
 *
 * This value must match the setting in your Prismic Repo.
 */
const LINK_RESOLVER_URL = new InjectionToken('LINK_RESOLVER_URL');
/**
 * A Guard to easily enable redirects for Prismic Previews.
 * You must provide `LINK_RESOLVER` and `LINK_RESOLVER_URL`.
 *
 * When a preview-token is present, this guard automatically
 * redirects based on the provided `LINK_RESOLVER`.
 *
 * If no token is present, the guard does nothing.
 *
 * Compiler-Flags:
 * - @dynamic (Allow lambda functions)
 */
class PreviewGuard {
    constructor(router, repoName, linkResolver, linkResolverUrl, defaultRoute = '/') {
        this.router = router;
        this.repoName = repoName;
        this.linkResolver = linkResolver;
        this.linkResolverUrl = linkResolverUrl;
        this.defaultRoute = defaultRoute;
        /**
         * Prismic supplies the preview token in a query param named `token`.
         */
        this.QUERY_PARAM_KEY = 'token';
        const endpoint = getEndpoint(this.repoName);
        this.client = createClient(endpoint);
    }
    canActivateChild(next, state) {
        if (state.url.startsWith(this.linkResolverUrl)) {
            const params = next.queryParamMap;
            if (!params.has(this.QUERY_PARAM_KEY)) {
                return this.router.parseUrl(this.defaultRoute);
            }
            const previewToken = params.get(this.QUERY_PARAM_KEY);
            const resolvedUrl = from(this.client.resolvePreviewURL({
                previewToken,
                linkResolver: this.linkResolver,
                defaultURL: this.defaultRoute
            }));
            return resolvedUrl.pipe(map(url => this.router.parseUrl(url)));
        }
        return true;
    }
}
PreviewGuard.ɵprov = ɵɵdefineInjectable({ factory: function PreviewGuard_Factory() { return new PreviewGuard(ɵɵinject(Router), ɵɵinject(REPOSITORY_NAME), ɵɵinject(LINK_RESOLVER), ɵɵinject(LINK_RESOLVER_URL), ɵɵinject(LINK_RESOLVER_DEFAULT_ROUTE, 8)); }, token: PreviewGuard, providedIn: "root" });
PreviewGuard.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
PreviewGuard.ctorParameters = () => [
    { type: Router },
    { type: String, decorators: [{ type: Inject, args: [REPOSITORY_NAME,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [LINK_RESOLVER,] }] },
    { type: String, decorators: [{ type: Inject, args: [LINK_RESOLVER_URL,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [LINK_RESOLVER_DEFAULT_ROUTE,] }, { type: Optional }] }
];

/**
 * Call this function in your `AppComponent`'s `ngOnInit()`.
 */
function handlePreview(client, repoName, linkResolver = doc => `/${doc.uid}`, defaultURL = '/', enabled = true) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        if (!enabled) {
            return;
        }
        const toolbarScript = document.createElement('script');
        toolbarScript.setAttribute('async', 'async');
        toolbarScript.setAttribute('defer', 'defer');
        toolbarScript.setAttribute('src', `https://static.cdn.prismic.io/prismic.js?new=true&repo=${repoName}`);
        const body = document.getElementsByTagName('body').item(0);
        body === null || body === void 0 ? void 0 : body.appendChild(toolbarScript);
        const isManualRef = (((_b = (_a = client) === null || _a === void 0 ? void 0 : _a.refState) === null || _b === void 0 ? void 0 : _b.mode) || '').toLowerCase() === 'manual';
        if (isManualRef) {
            client.resolvePreviewURL({
                defaultURL,
                linkResolver
            }).then(url => {
                if (location.pathname !== url && url !== defaultURL) {
                    location.replace(url);
                }
            });
        }
    });
}

var _a;
/**
 * Use this as the `ref` when constructing your client.
 */
const prismicPreviewRef = (_a = document.cookie
    .split('; ')
    .find((row) => row.startsWith(`${cookie.preview}`))) === null || _a === void 0 ? void 0 : _a.split('=')[1];

/**
 * Generated bundle index. Do not edit.
 */

export { LINK_RESOLVER, LINK_RESOLVER_DEFAULT_ROUTE, LINK_RESOLVER_URL, PreviewGuard, PrismicClientModule, REPOSITORY_NAME, RenderHtmlPipe, RenderImagePipe, SafePipe, handlePreview, prismicPreviewRef };
//# sourceMappingURL=ngx-prismic-client.js.map
